betty.project.extension.cotton_candy.search module - Betty documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# betty.project.extension.cotton_candy.search module

Provide Cotton Candy’s search functionality.

class betty.project.extension.cotton_candy.search.Index

  Bases: `object`

  Build search indexes.

  This is internal. It MAY be used anywhere in Betty’s source code, but MUST NOT be used by third-party code.

  __init__(ancestry: Ancestry, jinja2_environment: Environment, job_context: Context | None, localizer: Localizer)
  async build() → Sequence[_Entry]

    Build the search index.